@@ -36,6 +36,7 @@ from .assistants import AssistantsAPI
 from .conversations import ConversationsAPI
 from .utils import UtilsAPI, get_validated_data
 from .audio import AudioAPI
+from .image import ImageAPI
 from .protected import ProtectedAPI
 from .deprecated import deprecated, deprecated_class
 
@@ -122,6 +123,7 @@ class ScoutAPI:
         self.conversations = ConversationsAPI(self._base_url, self._headers)
         self.utils = UtilsAPI(self._base_url, self._headers)
         self.audio = AudioAPI(self._base_url, self._headers)
+        self.image = ImageAPI(self._base_url, self._headers)
         self.protected = ProtectedAPI(self._base_url, self._headers)
 
     # Generic requests
