@@ -21,6 +21,8 @@ from scouttypes.assistants import (
     QueryAssistantDataResponse,
     AssistantDataUpdateResponse,
     CreateAssistantDataResponse,
+    AssistantCustomFunctionsResponse,
+    FileType,
 )
 from .utils import get_validated_data
 
@@ -144,6 +146,22 @@ class AssistantsAPI:
 
         return AssistantInfoResponse.model_validate(response)
 
+    def get(self, assistant_id: str) -> AssistantInfoResponse:
+        """
+        Retrieve a specific assistant by its ID.
+
+        Args:
+            assistant_id (str): The ID of the assistant to retrieve.
+
+        Returns:
+            AssistantInfoResponse: The assistant object retrieved from the API.
+        """
+        response, status_code = RequestUtils.get(
+            url=f"{self._base_url}/api/assistants/{assistant_id}", headers=self._headers
+        )
+
+        return AssistantInfoResponse.model_validate(response)
+
     def list_all(self) -> List[AssistantPublicResponse]:
         """
         Retrieve a list of all assistants the token has access to.
@@ -210,13 +228,16 @@ class AssistantsAPI:
         self,
         assistant_id: str,
         file_path: str,
+        file_type: Optional[FileType] = None,
     ) -> AssistantFileUploadResponse:
         """
-        Upload a file to the knowledge section of a specific assistant.
+        Upload a file to a specific assistant.
 
         Args:
             assistant_id (str): The ID of the assistant to upload the file for.
             file_path (str): The local file path to the file to upload.
+            file_type (Optional[FileType]): The type of file to upload. Defaults to FileType.KNOWLEDGE.
+                Valid values: FileType.KNOWLEDGE, FileType.CUSTOM_FUNCTIONS, FileType.ASSISTANT_TEMPLATES, FileType.SHARED_CUSTOM_FUNCTIONS
 
         Returns:
             AssistantFileUploadResponse: The response object containing information about the uploaded file.
@@ -226,6 +247,10 @@ class AssistantsAPI:
         """
         with open(file_path, "rb") as f:
             files = {"file": f}
+            data = {}
+            if file_type is not None:
+                data["file_type"] = file_type.value
+
             local_headers = self._headers.copy()
             local_headers.pop("Content-Type")
 
@@ -233,6 +258,7 @@ class AssistantsAPI:
                 url=f"{self._base_url}/api/assistants/{assistant_id}/files",
                 headers=local_headers,
                 files=files,
+                data=data,
             )
         return AssistantFileUploadResponse.model_validate(response)
 
@@ -511,3 +537,19 @@ class AssistantsAPI:
         )
 
         return get_validated_data(response.get("result", {}), response_model)
+
+    def get_functions(self, assistant_id: str) -> AssistantCustomFunctionsResponse:
+        """
+        Retrieve custom functions for a specific assistant.
+
+        Args:
+            assistant_id (str): The ID of the assistant whose functions are to be retrieved.
+
+        Returns:
+            AssistantCustomFunctionsResponse: The custom functions for the assistant.
+        """
+        response, status_code = RequestUtils.get(
+            url=f"{self._base_url}/api/assistants/{assistant_id}/functions",
+            headers=self._headers,
+        )
+        return AssistantCustomFunctionsResponse.model_validate(response)
