@@ -20,8 +20,15 @@ class ProtectedAPI:
         Raises:
             ValueError: If the response is invalid or cannot be validated.
         """
+        protected_path = "/protected/"
+        final_path = (
+            path
+            if path.startswith(protected_path)
+            else protected_path + path.lstrip("/")
+        )
+
         response, status_code = RequestUtils.get(
-            url=f"{self._base_url}/api/protected/{path}",
+            url=f"{self._base_url}/api{final_path}",
             headers=self._headers,
         )
 
