@@ -4,14 +4,17 @@ import os
 import subprocess
 import shutil
 from pathlib import Path
-from typing import List, Optional
+from typing import List, Optional, Union
 from pydantic import BaseModel
+
+
 from .base_module import BaseModule
 from .pkg_module import PkgModule
 from ..config import Config
 from ..error_handler import FileSystemError, ModuleError, logger
 from ..types import GenericResponse, EmptyRequest
 from scoutsdk.api import ScoutAPI
+from scoutsdk import scout
 
 
 # Pydantic models for the config file
@@ -42,7 +45,7 @@ class ConfigAssistant(BaseModel):
     use_system_prompt: bool = False
     prompt_starters_text: Optional[List[str]] = None
     prompt_starters_path: Optional[List[str]] = None
-    assistant_files: List[ConfigAssistantFile] = []
+    assistant_files: List[Union[str, ConfigAssistantFile]] = []
     avatar_path: Optional[str] = None
     visibility_type: Optional[str] = None
     variables: Optional[dict] = None
@@ -88,12 +91,9 @@ class SyncModule(BaseModule):
 
     def _get_api_url(self) -> str:
         try:
-            scout_context_str = os.environ.get("SCOUT_CONTEXT")
-            if scout_context_str:
-                scout_context = json.loads(scout_context_str)
-                api_url = scout_context.get("SCOUT_API_URL", "")
-                if api_url:
-                    return api_url
+            api_url = scout.context.get("SCOUT_API_URL", "")
+            if api_url:
+                return api_url
         except Exception as e:
             logger.warning(f"Error parsing SCOUT_CONTEXT: {str(e)}")
         return ""
@@ -472,12 +472,6 @@ class SyncModule(BaseModule):
             for existing in existing_assistants:
                 if existing.id == assistant_id:
                     return True, assistant_id
-        else:
-            # If no ID is provided, try matching by name
-            for existing in existing_assistants:
-                if existing.name == assistant.name:
-                    self._update_deployed_assistant_id(assistant.id, existing.id)
-                    return True, existing.id
 
         return False, ""
 
@@ -554,7 +548,8 @@ class SyncModule(BaseModule):
         logger.debug(f"Force replacing file: {file_path.name}")
         scout_api.assistants.delete_file(assistant_id=assistant_id, file_uid=file_uid)
         scout_api.assistants.upload_file(
-            assistant_id=assistant_id, file_path=str(file_path)
+            assistant_id=assistant_id,
+            file_path=str(file_path),
         )
 
     def _upload_new_assistant_file(
@@ -575,7 +570,14 @@ class SyncModule(BaseModule):
         for file_item in assistant.assistant_files:
             # if the file name match existing files, update the file
 
-            filename = Path(file_item.filepath).name
+            if isinstance(file_item, str):
+                filepath = file_item
+                description = None
+            else:
+                filepath = file_item.filepath
+                description = file_item.description
+
+            filename = Path(filepath).name
             if filename in existing_filenames:
                 for file in existing_files:
                     if file.filename == filename:
@@ -583,7 +585,7 @@ class SyncModule(BaseModule):
                             assistant_id=deployed_id,
                             file_uid=file.id,
                             filename=filename,
-                            description=file_item.description,
+                            description=description,
                         )
 
     def _sync_assistant_ui(
